<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->
**Table of Contents**  *generated with [DocToc](https://github.com/thlorenz/doctoc)*

- [pynamodb-attributes](#pynamodb-attributes)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

# pynamodb-attributes

This Python 3 library contains compound and high-level PynamoDB attributes.
